@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 980 2021-03-12 06:12:33Z Lavender $
+# $Id: __init__.py 1109 2021-07-03 04:56:23Z Casey $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-03-12 14:12:33 +0800 (週五, 12 三月 2021) $
-# $Revision: 980 $
+# $Author: Casey $ (last)
+# $Date: 2021-07-03 12:56:23 +0800 (Sat, 03 Jul 2021) $
+# $Revision: 1109 $
 
 import os
 import sys
@@ -33,7 +33,7 @@ from fabric import Connection as _Connection
 from fabric import connection
 from fabric.connection import opens
 
-# patch 
+# patch
 from invoke.runners import Runner
 
 DEFAULT_MARIADB_PASSOWRD = os.environ.get(
@@ -48,7 +48,7 @@ DEPLOY_TEST_SERVER_USER = os.environ.get(
     'DEPLOY_TEST_SERVER_USER', 'nuwa')
 DEPLOY_TEST_SERVER_PASSWORD = os.environ.get(
     'DEPLOY_TEST_SERVER_PASSWORD', '@%)@5529')
-    
+
 _read_our_stdin = Runner.read_our_stdin
 
 def read_our_stdin(self, input_):
@@ -57,9 +57,44 @@ def read_our_stdin(self, input_):
         return bytes_
     else:
         return None
-        
+
 Runner.read_our_stdin = read_our_stdin
 
+def getBuildData(shPath, dataName):
+    with open(shPath, 'r') as f:
+        for line in f.readlines():
+            if ("%s=" % dataName in line) and ("#" not in line.lstrip()):
+                index = line.index("=") + 1
+                return line[index:].replace('\r\n', '').strip()
+    return None
+
+def showSplash():
+    import pyfiglet
+    cprint("-" * 79, "white", attrs=["bold"],)
+    cprint(pyfiglet.figlet_format('Nuwa Info', font="standard"),
+           "blue", attrs=["bold"],)
+
+    cprint(pyfiglet.figlet_format('Deploy', font="standard"),
+           "yellow", attrs=["bold"],)
+    cprint("-" * 79, "white", attrs=["bold"],)
+
+    if six.PY2:
+        cprint(
+            "Deploy is only run by python3.",
+            "blue",
+            "on_white",
+            attrs=["bold", "underline"],
+        )
+        sys.exit()
+    else:
+        cprint(
+            colored(
+                "When enter the shell, "
+                "you must press Enter twice to execute command.",
+                "yellow"
+            )
+        )
+        
 def getConnectKwargs(password=None, key=os.path.join("PrivateKey.key")):
     # put key
     if password:
@@ -69,14 +104,14 @@ def getConnectKwargs(password=None, key=os.path.join("PrivateKey.key")):
             return {"key_filename": key,}
         else:
             return None
-            
+
 def getOrCreateKey(username, keyPath=os.path.join("Keys")):
     if not os.path.exists(keyPath):
         os.mkdir(keyPath)
-    userPath = os.path.join(keyPath, username) 
+    userPath = os.path.join(keyPath, username)
     privateKeyPath = os.path.join(userPath, "PrivateKey.key")
     publicKeyPath = os.path.join(userPath, "PublicKey.key")
-    
+
     # check key
     if os.path.isdir(userPath):
         # get key
@@ -89,14 +124,14 @@ def getOrCreateKey(username, keyPath=os.path.join("Keys")):
         os.mkdir(userPath)
 
         key = RSA.generate(4096)
-        
+
         publicKey = key.publickey().exportKey('OpenSSH').decode("utf-8")
         privateKey = key.exportKey("PEM").decode("utf-8")
-        
+
         with open(publicKeyPath, 'w') as f:
-            
+
             f.write(publicKey)
-            
+
         with open(privateKeyPath, 'w') as f:
             privateKey = privateKey.replace(
                 "BEGIN PRIVATE KEY", "BEGIN RSA PRIVATE KEY")
@@ -104,8 +139,8 @@ def getOrCreateKey(username, keyPath=os.path.join("Keys")):
                 "END PRIVATE KEY", "END RSA PRIVATE KEY")
 
             f.write(privateKey)
-            
-            
+
+
     return (publicKey, privateKey, publicKeyPath, privateKeyPath)
 
 @decorator
@@ -124,10 +159,10 @@ def record(func, c, *args, **kwargs):
         raise
     finally:
         c.recordLogs()
-    
+
     return rt
- 
-# patch 
+
+# patch
 @opens
 def run(self, command, notRecord=False, **kwargs):
     """
@@ -152,26 +187,26 @@ def run(self, command, notRecord=False, **kwargs):
             "on_white",
             attrs=["bold", "underline"],
         )
-    
+
     if six.PY2 and not kwargs.get("pty"):
         kwargs["hide"] = True
-      
+
     if not notRecord:
         c = "%s: %s" % (command, str(datetime.datetime.now().time()))
         if hasattr(self, "commands"):
             self.commands.append(c)
         else:
             self.commands = [c]
-            
+
     if not "encoding" in kwargs:
         kwargs["encoding"] = "utf8"
-    
-    # with open("test.log", 'a+') as f:  
+
+    # with open("test.log", 'a+') as f:
         # result = self._run(self._remote_runner(), command, out_stream=f, err_stream=f, **kwargs)
     result = self._run(self._remote_runner(), command, **kwargs)
-    
+
     return result
-    
+
 def recordLogs(self):
     # get user
     if "key_filename" in self.connect_kwargs:
@@ -179,17 +214,17 @@ def recordLogs(self):
 
         with open(self.connect_kwargs["key_filename"], "r") as f:
             key = RSA.import_key(f.read())
-            
+
         publicKey = key.publickey().exportKey('OpenSSH').decode("utf-8")
-        
+
         result = self.run(
-            "cat ~/.ssh/authorized_keys | grep '%s'" % publicKey, 
+            "cat ~/.ssh/authorized_keys | grep '%s'" % publicKey,
             hide=True, notRecord=True)
         result = result.stdout
         username = re.findall(r"USERNAME=(\w+)", result)[0]
     else:
         username = "someone"
-        
+
     # get ip
     # request https://api.ipify.org/?format=json to get ip
     try:
@@ -199,10 +234,10 @@ def recordLogs(self):
         ip = {}
     finally:
         username = "%s(%s)" % (username, ip.get("ip", "unknown"))
-        
+
     # 跳脫
     commands = [cmd.replace("'", "'\\''") for cmd in self.commands]
-           
+
     # record
     date = datetime.datetime.now().date()
     msg = "Execute command by %s at %s" % (username, date)
@@ -213,33 +248,33 @@ def recordLogs(self):
             msg, "\\n".join(commands), "-" * len(msg))
     cmd = "echo -e '%s' >> ~/.deploy_history" % logs
     self.run(cmd, hide=True, notRecord=True)
-    
+
     # clean
     self.commands = []
-    
+
     return
-   
+
 def addLog(self, log):
     log = "%s: %s" % (log, str(datetime.datetime.now().time()))
     if hasattr(self, 'commands'):
         self.commands.append(log)
     else:
         self.commands = [log,]
-                
+
 connection.Connection.run = run
 connection.Connection.addLog = addLog
 connection.Connection.recordLogs = recordLogs
 
 def unixPath(*args):
     return os.path.join(*args).replace("\\", "/")
-    
+
 def prompt(msg):
     if six.PY2:
         result = raw_input(msg)
     else:
         result = input(msg)
     return result
-    
+
 def utf8(s, encodings=None, throw=True):
     """
     Convert a string (UNICODE or ANSI) to a utf8 string.
@@ -258,7 +293,7 @@ def utf8(s, encodings=None, throw=True):
 def configureDjango(*args, **kws):
     """
     Configure django settings by given arguments.
-    
+
     @param *args Arguments.
     @param **kws Keyword arguments.
     """
@@ -268,5 +303,5 @@ def configureDjango(*args, **kws):
 
     djangoSettings._wrapped = empty
     djangoSettings.configure(*args, **kws)
-    
-    django.setup()
\ No newline at end of file
+
+    django.setup()
